Enum PackageEntryValidationError
pub enum PackageEntryValidationError {
GetMetadataFailed(Error),
NotFound,
ExpectedSymlink,
ExpectedDirectory,
IncorrectSize(u64, u64),
IoError(Error),
HashMismatch(String, String),
}Expand description
An error that indicates that a specific file in a package archive directory seems to be corrupted.
Variants
GetMetadataFailed(Error)
An error occurred while reading the metadata of the file.
NotFound
The file does not exist.
ExpectedSymlink
The file is not a symbolic link.
ExpectedDirectory
The file is not a directory.
IncorrectSize(u64, u64)
The size of the file does not match the expected size.
IoError(Error)
An IO error occurred while reading the file.
HashMismatch(String, String)
The SHA256 hash of the file does not match the expected hash.