Enum ValidationMode
pub enum ValidationMode {
Skip,
Fast,
Full,
}Expand description
The mode in which the validation should be performed.
Variants
Skip
Only check if the package directory exists and contains a valid index.json. Does not validate individual files or paths.json. This is the fastest validation mode but provides minimal guarantees about package integrity.
Fast
Only check if the files exists. Do not check if the hashes match.
Full
Check if the files exists and the content matches the hashes.